import numpy as np
import matplotlib.pyplot as plt
import seaborn as sb
import pystan
import platform

sm = pystan.StanModel(file = 'choco_choice.stan')

freq_noclip = [55, 24, 16]
freq_clip = [38, 27, 30]

Data = {'freq_1': freq_noclip, 'freq_2':freq_clip}

fit = sm.sampling(data = Data,
                  n_jobs = 1 if platform.system() == 'Windows' else -1)
print(fit)

plt.rcParams['font.family'] = ['Yu Gothic', 'Noto Sans CJK JP', 'Hiragino Maru Gothic Pro']

p1_smpls = fit['p1']
p2_smpls = fit['p2']

def calc_entropy(p):
    return -p.T[0]*np.log2(p.T[0]) -p.T[1]*np.log2(p.T[1]) \
            -p.T[2]*np.log2(p.T[2])

entropies1 = calc_entropy(p1_smpls)
entropies2 = calc_entropy(p2_smpls)

ent1_hat = np.median(entropies1)
ent2_hat = np.median(entropies2)

sb.kdeplot(entropies1, label = 'No-clip')
sb.kdeplot(entropies2, label = 'Clip')
plt.title('Entropy: No-clip={0:.2f}, Clip={1:.2f}'.format(ent1_hat, ent2_hat))
plt.legend()
plt.savefig('FigEntropies.png')
plt.show()

p1_1_hat = np.median(fit['p1'].T[0])
p1_2_hat = np.median(fit['p1'].T[1])
p1_3_hat = np.median(fit['p1'].T[2])
sb.kdeplot(fit['p1'].T[0], label = 'p1[1]:ガーナ')
sb.kdeplot(fit['p1'].T[1], label = 'p1[2]:ベネズエラ')
sb.kdeplot(fit['p1'].T[2], label = 'p1[3]:エクアドル')
plt.legend()
plt.title('No-clip\nガーナ={0:.2f},  ベネズエラ={1:.2f},  エクアドル={2:.2f}'.format(
            p1_1_hat, p1_2_hat, p1_3_hat))
plt.savefig('Figp1.png')
plt.show()

p2_1_hat = np.median(fit['p2'].T[0])
p2_2_hat = np.median(fit['p2'].T[1])
p2_3_hat = np.median(fit['p2'].T[2])
sb.kdeplot(fit['p2'].T[0], label = 'p2[1]:ガーナ')
sb.kdeplot(fit['p2'].T[1], label = 'p2[2]:ベネズエラ')
sb.kdeplot(fit['p2'].T[2], label = 'p2[3]:エクアドル')
plt.legend()
plt.title('Clip\nガーナ={0:.2f},  ベネズエラ={1:.2f},  エクアドル={2:.2f}'.format(
            p2_1_hat, p2_2_hat, p2_3_hat))
plt.savefig('Figp2.png')
plt.show()

e1_smpls = np.sort(entropies1)
e2_smpls = np.sort(entropies2)

def SmallerEqProp(a, v):
    i = 0
    while v > a[i]:
        i += 1
        if i >= len(a):
            break
    prop = i / len(a)
    return prop

sum_prop = 0.0
for v in e1_smpls:
    sum_prop += (1 - SmallerEqProp(e2_smpls, v))
prop_Larger = sum_prop / len(e1_smpls)
print('Prop_Larger =', prop_Larger)

